;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xff33a3e8b110df0b11aaedbf976711e5 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xa0251b2cec2d38722704e2ff12044f19 . "./code.cg2js/cg-printing.fasl")
(#x3c73725e2cc7d2a9b92422891515caeb . "./code.cg2js/cg-caret.fasl")
(#x7c0e1654593bbf79d6acec805471997b . "./code.cg2js/cg-item-list.fasl")
(#xf8b34563706787a9da2374da30123375 . "./code.cg2js/cg-progress-indicator.fasl")
(#x67130a2e305c736a99d7d2d918e0c49f . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xf7bb9bf0dc23cdfb3888df350b8463e9 . "./code.cg2js/cg-outline.fasl")
(#x7af113512a10faac55c777ca85616da7 . "./code.cg2js/cg-palette.fasl")
(#x24be69fde079ddf9ff566b41bded6015 . "./code.cg2js/cg-selected-object.fasl")
(#x1f8a3437eea65ae5a783c54b2e6b0217 . "./code.cg2js/cg-status-bar.fasl")
(#x1d7fac91fa90d3eaaff97171d18d31ea . "./code.cg2js/cg-wrap-string.fasl")
(#x123e0214486b506be537863e0ebf637f . "./code.cg2js/cg-fill-texture.fasl")
(#xd361b37cbf2ab8686f96725659bd25e6 . "./code.cg2js/cg-layout.fasl")
(#x098914065bcad3869ce402684bb48c55 . "./code.cg2js/cg-timer.fasl")
(#x892c31620dee6c5cbce7b34fbb4ee3c9 . "./code.cg2js/cg-dialog-item.fasl")
(#x86b18b9ae96a701596d59a16225df9a0 . "./code.cg2js/cg-button.fasl")
(#x7769a122c9fec98e7507a12815d4c4a9 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x207c4119128e3c0b88c53f2ef588e0e3 . "./code.cg2js/cg-tray.fasl")
(#xee182cd229d432d8678eeade8520cf14 . "./code.cg2js/cg-plot-widget.fasl")
(#xd0d1d95ab0e9f06e774926a3a67e2014 . "./code.cg2js/cg-pixmap.fasl")
(#x9c4b144d8688a559137de76fa6955049 . "./code.cg2js/cg-font-dialog.fasl")
(#x81ab7fabdaf6eda24189b0c766df436b . "./code.cg2js/cg-os-widget.fasl")
(#x234049a132fbad3b62c7c534cfb8c05b . "./code.cg2js/cg-text-or-combo.fasl")
(#x8a2b6a1b1bc6eea02e745a31d2719db4 . "./code.cg2js/cg-trackbar.fasl")
(#x1fc91472433072615e4e5f35df835b35 . "./code.cg2js/cg-up-down-control.fasl")
(#x518a1f259f2d47c9184210adfa3f4cb6 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x12c5c2204f3a8d2fa9f9d6b3fa4e8ae6 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x9af678d5c085d716631fb762fda42dbb . "./code.cg2js/cg-intersect-posbox.fasl")
(#x65bcef14d3219b13fa71228155bace94 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xcd0a030080374061c43966e912bc920f . "./code.cg2js/cg-chart-widget.fasl")
(#x1ef3d576a7064aabb24ad9ca762376da . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x97377edc0c199ab25ab83586c8c1baab . "./code.cg2js/cg-group-box.fasl")
(#x53c2da0e1d1b0756ebbe190f01103083 . "./code.cg2js/cg-static-text.fasl")
(#x74a72fcc238da4079bc69e9ba5dc9f1b . "./code.cg2js/cg-class-slot-grid.fasl")
(#x670449f612f2dabe6828d96750f0bfec . "./code.cg2js/cg-color-dialog.fasl")
(#xfa414ba54bad488e9415751ea0532c63 . "./code.cg2js/cg-intersect.fasl")
(#xf618d4c90e000d0937e042d867b6782a . "./code.cg2js/cg-gesture-emulation.fasl")
(#x4696fc73ac4be5299cf9398d9bd36006 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x84f8e90988c1893c84a36a9b378f1254 . "./code.cg2js/cg-html-dialog.fasl")
(#x2df3c1103e213b66b59f0e417bf16494 . "./code.cg2js/cg-lettered-menu.fasl")
(#x9fb51ef896ee60946aac72e0d537cd81 . "./code.cg2js/cg-class-grid.fasl")
(#x183b36bdc963a63d3f41197a8deef536 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x9c54afca80e70ea7109bc81b1846aa46 . "./code.cg2js/cg-calendar.fasl")
(#x35413d6b0ef92fc1626686e771e256fd . "./code.cg2js/cg-editable-text.fasl")
(#x9e01de58e40e97b2b0481b7784651e89 . "./code.cg2js/cg-property.fasl")
(#x16c42a2627ab4e1c74826cfd1dad4730 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xb50616a6c08bf9d1779ab60d339ea48b . "./code.cg2js/cg-grid-widget.fasl")
(#xfa880982fe7dae81e4934e64c11c4862 . "./code.cg2js/cg-paren-matching.fasl")
(#xbf2a5b8fba40ba4056c52442f6028227 . "./code.cg2js/cg-dev.fasl")
(#xbafd7277e251af11470ca1ff5a782d08 . "./code.cg2js/cg-drawable.fasl")
(#xfd5ecb25f13316cf58654fcb901e4ed2 . "./code.cg2js/cg-curve.fasl")
(#xd6bb06ecb0c3e6021ca13dcd6971595a . "./code.cg2js/cg-lisp-widget.fasl")
(#xd82fb3ccf8f4d8dcfe269a6960e208bc . "./code.cg2js/cg-dde-utils.fasl")
(#x7f34b11cf9473ea827fbaf3a7136e3f4 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x3d1a80ed113096e55e94311b65b553a2 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xba690c7d4c5717a1236326692726b2f8 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xa2c15199f20d9d4901fd5936145517e4 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x726de3990b7502cb85e1eb0d887f45d9 . "./code.cg2js/cg-lamp.fasl")
(#x6c4476a41826f506b284eb026e054b01 . "./code.cg2js/cg-common-control.fasl")
(#xb92074ce9706efe264159be9ed905ca0 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x4d43a55f4823fc2e4d4cca07d75e997b . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xe6b562cd6a5f1cfdc031f6db0257e563 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x4264ce792333c4fab644bf34874761b4 . "./code.cg2js/cg-project-window.fasl")
(#x4c08f38f2d8e60a7961a3fdd5b9b414f . "./code.cg2js/cg-sample-file-menu.fasl")
(#xc1f26bb2cf2ac25b49125dcee4c8faab . "./code.cg2js/cg-class-support.fasl")
(#x60771b6dfd478608388fab8abe3d541f . "./code.cg2js/cg-multi-picture-button.fasl")
(#x8e2d38555273f832aaeafe02687afd0e . "./code.cg2js/cg-yes-no-list.fasl")
(#x91dd37a7280604a3b363920d47ea8b6a . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xe21adf486604e7744900b97814868290 . "./code.cg2js/cg-string-dialog.fasl")
(#xcc09e630a5b36fb13996fbccab5433ca . "./code.cg2js/cg-menu-tooltip.fasl")
(#x4e057a149d4a5bd75094c6757c863b08 . "./code.cg2js/cg-dropping-outline.fasl")
(#x4751a448c917fdf26ac3f963b65d3350 . "./code.cg2js/cg.fasl")
(#x7fc4f7a430c016956ae9924c2fb1e53b . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x3c1e9aa47ab2ed0ae7154185074178bc . "./code.cg2js/cg-scaling-stream.fasl")
(#x537a08257f5c83d283593d8cbe13847a . "./code.cg2js/cg-yes-no-string.fasl")
(#x15cb46af49254adcd580f7f64ab46475 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x1d92f3a06cf46fddd5a62694ec78c5b1 . "./code.cg2js/cg-web-browser.fasl")
(#x5c336b17b9da22794cec0208624241cb . "./code.cg2js/cg-clipboard-stack.fasl")
(#xf7173c85c6a15d32aef46ffb65c8e027 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xa6482599e6c7f58bd377ae1853dbc8ec . "./code.cg2js/cg-message-dialog.fasl")
(#xe0818009a987cb545d2d40ab93b56941 . "./code.cg2js/cg-comtab.fasl")
(#xf1ffe3c86b7f108f056cb1c43f11e8a0 . "./code.cg2js/cg-base.fasl")
(#x22637932856e9efd0ddcb1774fa453b6 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xe473add3cb1f5b842512a123df650b96 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x8928d812e072d86ba2e7ff4904803095 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x362b39fc4018a26e25c82805e783bdcf . "./code.cg2js/cg-utility-dialog.fasl")
(#x8334bedb7a94086596e33d7e8a6a56cc . "./code.cg2js/cg-object-editor.fasl")
(#x073d3061c6c5af73b5edd0c2a2f663db . "./code.cg2js/cg-edit-in-place.fasl")
(#xb70cd46e17a514aa35ec35b52423d210 . "./code.cg2js/cg-radio-button.fasl")
(#x0752d11189b7a9e95011d5f42a929ffa . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xdb2e3fc7671164d229aaa813c19f6c60 . "./code.cg2js/cg-nodes.fasl")
(#xc21577e39633f4815c0a88880d562e3a . "./code.cg2js/cg-get-position.fasl")
(#x110445a46b850e975bbdd01a8d88810d . "./code.cg2js/cg-directory-dialog.fasl")
(#x4977aa64d522cb2bae281bb28ad84622 . "./code.cg2js/cg-lisp-text.fasl")
(#x9731e897d763336332e8b3acd905248f . "./code.cg2js/cg-combo-box.fasl")
(#x3bac3373d4737d4a487fcde751110cc1 . "./code.cg2js/cg-text-widget.fasl")
(#xe6a6c071590dd4218233700d5d36d0ca . "./code.cg2js/cg-list-view.fasl")
(#x38b21f04c194e4522cfbe75e6d14234d . "./code.cg2js/cg-header-control.fasl")
(#xffffc9ac513bd7b4b86bc177e9ffef84 . "./code.cg2js/cg-graphics-context.fasl")
(#x85c0dbef0660b0f7630ad373ec4f8084 . "./code.cg2js/cg-get-pixmap.fasl")
(#xf448992e75e78f399582642e36250d02 . "./code.cg2js/cg-menu.fasl")
(#x1a24e6767f23e7d4de208482d0c5a0c0 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x65c493dd0cdb891c6e6869968737ea44 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x2800239145f6702cd345380207095f34 . "./code.cg2js/cg-tooltip.fasl")
(#x876e00d9eae2a441f0a4078a53b0b14a . "./code.cg2js/cg-html-widget.fasl")
(#x1961b5903d043575cec4c21650699182 . "./code.cg2js/cg-choice-list.fasl")
(#x89e51fb389d392e01e768a9157b51d2e . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x9f5ef782453570c70b434a1aa84884bf . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x1aa9fd0aa376a17fe9683867b2e31b6e . "./code.cg2js/cg-icon.fasl")
(#x5ec163675a21749fe2fe2f2684721420 . "./code.cg2js/cg-acache.fasl")
(#x56e44cb44ceab83cfd45252aac1e69f2 . "./code.cg2js/cg-template-string.fasl")
(#x3fbbdfb085f4161a378d72fe7dbe5033 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x2f268940fef7299244e4cf95ba67ce98 . "./code.cg2js/cg-toggling-widget.fasl")
(#xcc1aff7d176ad22655797e0a9b507a13 . "./code.cg2js/cg-tab-control.fasl")
(#x380b6f6b8dee0663af80955692bcbb0c . "./code.cg2js/cg-split-bar.fasl")
(#x9421efb70cab740dfd702372051582e7 . "./code.cg2js/cg-picture-widget.fasl")
(#x9295c341b9ae7c8f7b50eff0a16202b7 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x73ac6d4dfb1722ca4a4d34ce24aec432 . "./code.cg2js/cg-choose-printer.fasl")
(#x91f24cfc974aa4d30fb65fa63922079d . "./code.cg2js/cg-os-window.fasl")
(#x78d5cd26f786fdc6f6ea40f99418315a . "./code.cg2js/cg-scroll-bar.fasl")
(#xdc7f7a1d7bec79248fd243c98290f79a . "./code.cg2js/cg-clipboard.fasl")
(#xc07c256e286fc8cb688e265774c6e1ee . "./code.cg2js/cg-find-string-dialog.fasl")
(#xbd1a7bec5c4f4205c3c47c445dfdb1a8 . "./code.cg2js/cg-hotspot.fasl")
(#x7f66f3898907e0ee8a96aa09ed980707 . "./code.cg2js/cg-rich-edit.fasl")
(#x575a68af14002d8fc91446dabe9d498f . "./code.cg2js/cg-check-box.fasl")
(#x79aee949688fcf1f155fe01af3d8fa28 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x91bad23acde8f5945bc4855193f19ad2 . "./code.cg2js/cg-file-dialog.fasl")
(#x8dbfe10d63b665b5c0730c7fba5088a1 . "./code.cg2js/cg-toolbar.fasl")
(#xe71fb18c1b0b0846caed723fac48a7bc . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x478ccef1e7388e5d0a362d6a42b31edd . "./code.cg2js/cg-chart-or-plot.fasl")
(#x2c4c5db22788bbcf25401427f9466d7f . "./code.cg2js/cg-shortcut-menu.fasl")
(#x6599795ff114acc854803d259730df87 . "./code.idejs/ide-project.fasl")
(#x5c3fd94d2c85df2db5d812518ecb2f54 . "./code.idejs/ide-intro.fasl")
(#xa03bb48a4d4035cd321c712a311b185a . "./code.idejs/ide-find-in-files.fasl")
(#x46de9f88126a65ab79f4f6b346444e53 . "./code.idejs/ide-grapher.fasl")
(#xe1e688d76d637984864415629e448948 . "./code.idejs/ide-inspector.fasl")
(#xbab4912e946520022b5e5a80e09acfa1 . "./code.idejs/ide-editor.fasl")
(#xde827d503bc715ba0f4f64032299cf09 . "./code.idejs/ide-window-list.fasl")
(#x2eb59d6a633ae39397e81cfaf8eaf821 . "./code.idejs/ide-process-browser.fasl")
(#xcd663039f2b738dde40720cb6b33e122 . "./code.idejs/ide-patch-dialog.fasl")
(#xd496c97dae198ecc90b05be9c5640666 . "./code.idejs/ide-class-grapher.fasl")
(#x20243596a9ee764efe5074a6d320298e . "./code.idejs/ide-base.fasl")
(#xfa871bb4b14ae9fb863b309f51e242e8 . "./code.idejs/ide.fasl")
(#x44de083c62a2b8c66c5f51d76b98098b . "./code.idejs/ide-trace.fasl")
(#x4f87816179ecc4f6070afb5a044f3eb4 . "./code.idejs/ide-form.fasl")
(#x7ecd934655036fa11c5db4df91a8da5b . "./code.idejs/ide-find-definitions.fasl")
(#x1045998124581f846b9ce83955516399 . "./code.idejs/ide-apropos.fasl")
(#xa5f8d6d48bd3678aea05e963e38b055a . "./code.idejs/ide-class-browser.fasl")
(#xa1db0eec9054c272e44099b143e2b8ed . "./code.idejs/ide-navigator.fasl")
(#xe8ad93cc497213d15cd7200a221b5764 . "./code.idejs/ide-clipboard.fasl")
(#x2f0bfc268a055cfc086534691b67cda9 . "./code.idejs/ide-acache.fasl")
(#x8ca904b926537fe310003ffc07d6dedd . "./code.idejs/ide-keyshort.fasl")
(#x76c2c3829ef6c3c6ceeb3854e8e9f5fb . "./code.idejs/ide-package-list.fasl")
(#xeaa72c185c83c3388912c5334ef83b8b . "./code.idejs/ide-dev.fasl")
(#xe396744af4d34e05e734175c54f8cafc . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
